=begin
  locale/posix.rb 

  Copyright (C) 2002-2007  Masao Mutoh

  You may redistribute it and/or modify it under the same
  license terms as Ruby.

  $Id: posix.rb,v 1.2 2007/11/08 16:44:22 mutoh Exp $
=end

require 'locale/base'

module Locale 
  # Locale::SystemPosix module for Posix OS (Unix)
  # This is a low-level class. Application shouldn't use this directly.
  module SystemPosix
    extend SystemBase
    @@alias_cache = nil

    class << self
      def resolve_alias(loc)
	alias_cache.has_key?(loc) ? alias_cache[loc] : loc
      end

      def alias_cache(reload = false)
	@@alias_cache && !reload and return @@alias_cache
	%w(/usr/share/locale/locale.alias
	   /usr/share/gettext/intl/locale.alias
	   /usr/lib/X11/locale/locale.alias
	   /usr/share/X11/locale/locale.alias).each do |alias_file|
	  File.readable? alias_file or next
	  @@alias_cache = {}
	  open(alias_file) do |alias_io|
	    alias_io.each do |line|
	      aname, cname = line.split(/\s+/, 2)
	      @@alias_cache[aname.chomp] = cname.chomp
	    end
	  end
	  break
	 end
	@@alias_cache
      end

      def locale_from_env
	locale = nil
	# At least one environment valiables should be set on *nix system.
	[ENV["LC_ALL"], ENV["LC_MESSAGES"], ENV["LANG"]].each do |loc|
	  if loc != nil and loc.size > 0
	    locale = Locale::Object.new(resolve_alias(loc))
	    locale.charset ||= get_charset(locale)
	    break
	  end
	end
	locale
      end
    end

  end
  @@locale_system_module = SystemPosix
end

